(* Copyright (C) 2013, Thomas Leonard
 * See the README file for details, or visit http://0install.net.
 *)

val handle_complete : Zeroinstall.General.config -> string list -> unit
